@@ -1583,6 +1583,23 @@ spcdevVisit(dev, hierName, trans)
 	drain = &dev->dev_terms[2];
     subnode = dev->dev_subsnode;
 
+    /* Check for minimum number of terminals */
+
+    switch(dev->dev_class)
+    {
+	case DEV_SUBCKT:
+	case DEV_RSUBCKT:
+	    break;
+	default:
+	    if (dev->dev_nterm < 2)
+	    {
+		TxError("Device other than a subcircuit has only "
+			"one terminal\n");
+		return 0;
+	    }
+	    break;
+    }
+
     /* Original hack for BiCMOS, Tim 10/4/97, is deprecated.	*/
     /* Use of "device bjt" preferred to "fet" with model="npn".	*/
 
